/**********
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
**********/
/*
    A C++ program to parse DJI's ".txt" log files (recorded by the "DJI Go 4" app).
    Version 2020-04-15

    Copyright (c) 2020 Live Networks, Inc.  All rights reserved.
    For the latest version of this program (and more information), visit http://djilogs.live555.com

    Parsing RECOVER records within DJI ".txt" files.
    Implementation.
*/

#include "RecordAndDetailsParser.hh"

void RecordAndDetailsParser::parseRecord_RECOVER(u_int8_t const*& ptr, u_int8_t const* limit) {
  // Note: Some of the field lengths here may have been different in older ".txt" versions

  if (limit-ptr < 109) return; // This record is smaller than we expect; we can't handle it

  // RECOVER.droneType.RAW: 1 byte unsigned:
  noteByteField("RECOVER.droneType.RAW", ptr, limit);

  // RECOVER.appType.RAW: 1 byte unsigned:
  noteByteField("RECOVER.appType.RAW", ptr, limit);

  // RECOVER.appVersion: 3 bytes;
  note3ByteVersionField("RECOVER.appVersion", ptr, limit);

  // RECOVER.aircraftSn: string (length 16):
  noteStringField("RECOVER.aircraftSn", ptr, 16, limit);

  // RECOVER.aircraftName: string (length 32):
  noteStringField("RECOVER.aircraftName", ptr, 32, limit);

  // RECOVER.activeTimestamp: 8 bytes little-endian, in Unix time format:
  note8ByteTimestampField("RECOVER.activeTimestamp", ptr, limit);

  // RECOVER.cameraSn: string (length 16):
  noteStringField("RECOVER.cameraSn", ptr, 16, limit);

  // RECOVER.rcSn: string (length 16):
  noteStringField("RECOVER.rcSn", ptr, 16, limit);

  // RECOVER.batterySn: string (length 16):
  noteStringField("RECOVER.batterySn", ptr, 16, limit);
}
